@@ -1,4 +1,4 @@
-# MAPLAT  (C) 2008-2010 Rene Schickbauer
+# MAPLAT  (C) 2008-2011 Rene Schickbauer
 # Developed under Artistic license
 # for Magna Powertrain Ilz
 package Maplat::Helpers::DBSerialize;
@@ -9,10 +9,10 @@ use warnings;
 # postgres TEXT field (achieved through Storable and Base64 encoding)
 
 use base qw(Exporter);
-our @EXPORT = qw(dbfreeze dbthaw); ## no critic
-our $VERSION = 0.994;
+our @EXPORT = qw(dbfreeze dbthaw dbderef); ## no critic (Modules::ProhibitAutomaticExportation)
+our $VERSION = 0.995;
 
-use YAML::XS;
+use YAML::Syck;
 use Carp;
 
 sub dbfreeze {
@@ -33,6 +33,20 @@ sub dbthaw {
     
     return Load($data);
 }
+
+sub dbderef {
+    my ($val) = @_;
+    
+    return if(!defined($val));
+    
+    while(ref($val) eq "SCALAR" || ref($val) eq "REF") {
+        $val = $$val;
+        last if(!defined($val));
+    }
+    
+    return $val;
+}
+
 1;
 __END__
 
@@ -62,13 +76,18 @@ Takes one argument, the reference to the data structure to be encoded. Returns a
 
 Takes one argument, a text string encoded by dbfreeze(). Returns a reference to a data structure.
 
+=head2 dbderef
+
+Takes one argument, a scalar that (possibly) needs derefencing. This is a helper function that should(tm) do
+the right things in most of the cases and return the correctly derefenced scalar. YMMV
+
 =head1 AUTHOR
 
 Rene Schickbauer, E<lt>rene.schickbauer@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2010 by Rene Schickbauer
+Copyright (C) 2008-2011 by Rene Schickbauer
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
