@@ -1,4 +1,4 @@
-# MAPLAT  (C) 2008-2010 Rene Schickbauer
+# MAPLAT  (C) 2008-2011 Rene Schickbauer
 # Developed under Artistic license
 # for Magna Powertrain Ilz
 package Maplat::Helpers::Logo;
@@ -8,11 +8,11 @@ use warnings;
 use 5.008000;
 
 use base qw(Exporter);
-our @EXPORT= qw(MaplatLogo); ## no critic
+our @EXPORT= qw(MaplatLogo); ## no critic (Modules::ProhibitAutomaticExportation)
 
-our $VERSION = 0.994;
+our $VERSION = 0.995;
 
-our @lines;
+my @lines;
 
 sub MaplatLogo {
         my ($appname, $version) = @_;
@@ -62,7 +62,7 @@ Rene Schickbauer, E<lt>rene.schickbauer@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2010 by Rene Schickbauer
+Copyright (C) 2008-2011 by Rene Schickbauer
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
