@@ -1,16 +1,19 @@
-# MAPLAT  (C) 2008-2010 Rene Schickbauer
+# MAPLAT  (C) 2008-2011 Rene Schickbauer
 # Developed under Artistic license
 # for Magna Powertrain Ilz
 package Maplat::Helpers::MailLogger;
 use strict;
 use warnings;
 
-use 5.008000;
+# This file does major layouting. So, allow magic numbers
+## no critic (ValuesAndExpressions::ProhibitMagicNumbers)
+
+use 5.010;
 
 use base qw(Exporter);
 #our @EXPORT= qw();
 
-our $VERSION = 0.994;
+our $VERSION = 0.995;
 
 use Maplat::Helpers::Strings qw(tabsToTable);
 use Maplat::Helpers::DateStrings;
@@ -117,7 +120,7 @@ sub finish {
                 );
 
     if(!sendmail(%mail)) {
-        print {$self->{fh}} "Can't send status mail: " . $Mail::Sendmail::error . "\n";
+        print {$self->{fh}} "Can't send status mail: " . $Mail::Sendmail::error . "\n"; ## no critic (Variables::ProhibitPackageVars)
     } else {
         print {$self->{fh}} "Status mail sent";
     }
@@ -331,7 +334,7 @@ Rene Schickbauer, E<lt>rene.schickbauer@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2010 by Rene Schickbauer
+Copyright (C) 2008-2011 by Rene Schickbauer
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
