@@ -1,4 +1,4 @@
-# MAPLAT  (C) 2008-2010 Rene Schickbauer
+# MAPLAT  (C) 2008-2011 Rene Schickbauer
 # Developed under Artistic license
 # for Magna Powertrain Ilz
 
@@ -8,8 +8,9 @@ use warnings;
 
 use base qw(Maplat::Web::BaseModule);
 use Maplat::Helpers::DateStrings;
+use Maplat::Helpers::DBSerialize;
 
-our $VERSION = 0.994;
+our $VERSION = 0.995;
 
 
 use Carp;
@@ -51,9 +52,7 @@ sub get {
     my $dirstatus = $memh->get("dircleanstatus");
     my @dirlines;
     if($dirstatus) {
-        while(ref($dirstatus) eq "REF") {
-            $dirstatus = $$dirstatus;
-        }
+        $dirstatus = dbderef($dirstatus);
         foreach my $dir (sort keys %{$dirstatus}) {
             my %hline = (
                 path        => $th->quote($dir),
@@ -123,7 +122,7 @@ Rene Schickbauer, E<lt>rene.schickbauer@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2010 by Rene Schickbauer
+Copyright (C) 2008-2011 by Rene Schickbauer
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
