@@ -1,4 +1,4 @@
-# MAPLAT  (C) 2008-2010 Rene Schickbauer
+# MAPLAT  (C) 2008-2011 Rene Schickbauer
 # Developed under Artistic license
 # for Magna Powertrain Ilz
 package Maplat::Web::Themes;
@@ -7,8 +7,9 @@ use warnings;
 
 use base qw(Maplat::Web::BaseModule);
 use Maplat::Helpers::DateStrings;
+use Maplat::Helpers::DBSerialize;
 
-our $VERSION = 0.994;
+our $VERSION = 0.995;
 
 use Carp;
 
@@ -90,11 +91,12 @@ sub prerender {
     my $seth = $self->{server}->{modules}->{$self->{usersettings}};
     my ($ok, $templname) = $seth->get($webdata->{userData}->{user}, "UserLayout");
     
-    if($ok && defined($templname) && $$templname ne "") {
+    if(defined($templname)) {
+        $templname = dbderef($templname);
+    }
+    if($ok && defined($templname) && $templname ne "") {
         # Now, we have to check if this theme is still available
         $ok = 0;
-        # Deref
-        $templname = $$templname;
         foreach my $theme (@{$self->{Themes}}) {
             if($templname eq $theme->{template}) {
                 $ok = 1;
@@ -187,7 +189,7 @@ Rene Schickbauer, E<lt>rene.schickbauer@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2010 by Rene Schickbauer
+Copyright (C) 2008-2011 by Rene Schickbauer
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
