@@ -1,4 +1,4 @@
-# MAPLAT  (C) 2008-2010 Rene Schickbauer
+# MAPLAT  (C) 2008-2011 Rene Schickbauer
 # Developed under Artistic license
 # for Magna Powertrain Ilz
 
@@ -10,7 +10,7 @@ use Maplat::Helpers::DateStrings;
 
 use Carp;
 
-our $VERSION = 0.994;
+our $VERSION = 0.995;
 
 sub new {
     my ($proto, %config) = @_;
@@ -99,6 +99,10 @@ sub work {
         $memh->set_activecommand($activecommand);
         
         my $printarglist = "(no args)";
+        if(!defined($command->{arguments})) {
+            my @temp;
+            $command->{arguments} = \@temp;
+        }
         if(@{$command->{arguments}}) {
             $printarglist = "(" . join(",", @{$command->{arguments}}) . ")";
         }
@@ -206,7 +210,7 @@ Rene Schickbauer, E<lt>rene.schickbauer@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2010 by Rene Schickbauer
+Copyright (C) 2008-2011 by Rene Schickbauer
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
